@@ -1,12 +1,9 @@
-{-# LANGUAGE DeriveFunctor #-}
-{-# LANGUAGE DeriveFoldable #-}
-{-# LANGUAGE DeriveTraversable #-}
-{-# LANGUAGE FlexibleInstances #-}
+{-# LANGUAGE DeriveTraversable #-}  -- implies DeriveFunctor, DeriveFoldable
+{-# LANGUAGE FlexibleInstances #-}  -- implies TypeSynonymInstances
 {-# LANGUAGE LambdaCase #-}
 {-# LANGUAGE PatternGuards #-}
 {-# LANGUAGE PatternSynonyms #-}
 {-# LANGUAGE RecordWildCards #-}
-{-# LANGUAGE TypeSynonymInstances #-}
 
 {-
     BNF Converter: Abstract syntax
@@ -574,7 +571,7 @@ mapRhs f r = r { rhsRule = f $ rhsRule r }
 -- Exp1, Exp2... in case of coercion
 rulesForNormalizedCat :: CF -> Cat -> [Rule]
 rulesForNormalizedCat cf cat =
-    [r | r <- cfgRules cf, isParsable r, normCat (valCat r) == cat]
+    [r | r <- cfgRules cf, normCat (valCat r) == cat]
 
 -- | As rulesForCat, but this version doesn't exclude internal rules.
 rulesForCat' :: CF -> Cat -> [Rule]
