@@ -186,6 +186,10 @@ parseCF opts target content = do
             , printNames xs
             ]
 
+  -- Print errors for empty comment deliminters
+  unlessNull (checkComments cf) $ \ errs -> do
+    dieUnlessForce $ unlines errs
+
   -- Print warnings if user defined nullable tokens.
   Fold.mapM_ dieUnlessForce $ checkTokens cf
 
@@ -370,7 +374,7 @@ transDef = \case
 -- | Translate @separator [nonempty] C "s"@.
 --   The position attached to the generated rules is taken from @C@.
 --
---   (Ideally, we would take them from the @terminator@ keyword.
+--   (Ideally, we would take them from the @separator@ keyword.
 --   But BNFC does not deliver position information there.)
 --
 --   If the user-provided separator consists of white space only,
@@ -413,6 +417,8 @@ terminatorRules size c0 s = do
   where
   term = if null s then id else (Right s :)
 
+-- | Expansion of the @coercion@ pragma.
+
 coercionRules :: Abs.Identifier -> Integer -> Trans [Rule]
 coercionRules c0 n = do
   WithPosition pos c <- transIdent c0
@@ -424,6 +430,8 @@ coercionRules c0 n = do
     , [ urule (CoercCat c n)     [Right "(", Left (Cat c), Right ")"] ]
     ]
 
+-- | Expansion of the @rules@ pragma.
+
 ebnfRules :: Abs.Identifier -> [Abs.RHS] -> Trans [Rule]
 ebnfRules (Abs.Identifier ((line, col), c)) rhss = do
   file <- asks lbnfFile
@@ -507,6 +515,16 @@ transExp xs = loop
 
 --------------------------------------------------------------------------------
 
+-- | Check if any comment delimiter is null.
+checkComments :: CFG f -> [String]  -- ^ List of errors.
+checkComments cf = concat
+  [ [ "Empty line comment delimiter."        | CommentS ""      <- prags ]
+  , [ "Empty block comment start delimiter." | CommentM ("", _) <- prags ]
+  , [ "Empty block comment end delimiter."   | CommentM (_, "") <- prags ]
+  ]
+  where
+  prags = cfgPragmas cf
+
 -- | Check if any of the user-defined terminal categories is nullable.
 checkTokens :: CFG f -> Maybe String
 checkTokens cf
